@@ -1,6 +1,6 @@
 import requests
 
-from . import BASE_URL
+from ._base_url import BASE_URL
 from .other import get_available_language
 
 
