@@ -1,5 +1,6 @@
 import requests
-from . import BASE_URL, emoji
+from . import emoji
+from ._base_url import BASE_URL
 
 
 def get_message(chat_id: int, key: str) -> str:
