@@ -1,6 +1,6 @@
 import requests
 from typing import Union
-from . import BASE_URL
+from ._base_url import BASE_URL
 
 SUDO_URL = f"{BASE_URL}/sudos/"
 
